==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/preview.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
KWL_CheckLocalReferer(1);
if (!KWL_HcodeCheck(KWL_GetConf("SiteKey"),$hcode)) KWL_Redirect("$CONF[G_URL]");

ini_set('upload_max_filesize',$CONF['FILE_MAX_SIZE']);

$head = _PREVIEW;

$AuthorEmail = KWL_EmailCheck($AuthorEmail);
if (empty($Author) || empty($AuthorEmail) || empty($Content) || empty($Heading)) {
   KWL_ShowError(_ERROR_INPUT_STORY);
}

/* check Author without login */
if (!$CONF['NoLogin_User'] && !$login) {
   if (SqlCount("T_Users","name",trim($Author))) KWL_ShowError(_MUST_LOGIN);
}

if (empty($Summary)) $summ = KWL_genSummary($Content);
else $summ = KWL_genSummary($Summary);

if (isset($_POST['killfile']) && $_POST['killfile'] == _UPLOADED_FILE_DEL) {
   @unlink("$CONF[G_PATH]/upload/$Topic/$updir/$file[name]");
   @unlink("$CONF[G_PATH]/upload/$Topic/$updir/$file[name]"."_t.jpg");
   @rmdir("$CONF[G_PATH]/upload/$Topic/$updir");
   unset($file,$updir);
}

if (!empty($file)) {
} else if (!$CONF['FILE_UPLOAD'] || empty($_FILES['userfile']['name'])) {
   $file['name'] = '';
   $updir = '';
   $file['size'] = 0;
} else {
   $updir = date("YmdHis",time());
   $file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/upload/$Topic",$updir,$CONF['FILE_MAX_SIZE']);
   if (!is_array($file)) KWL_ShowError(_UPLOAD_FAILED);	
}

settype($mode,"string");
if ($mode==_SUBMIT) {
   $rid	= KWL_getRid();
   if (!$CONF['Moderation'] || $CONF['admin_login'] || $CONF['Moderation']==3) 
      $valflag	= "'Y',";
   else $valflag	= "'N',";

	$Content = trim($Content);
	$summ = trim($summ);
   list($Heading,$Author) = KWL_PrepareHtml($Heading,$Author);
	if ($AuthorURL) $AuthorURL = KWL_UrlCheck($AuthorURL);
   if ($CONF['NoLogin_User']) KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL);
	if ($CONF['ENABLE_EDIT'] && !$login) $passwd = crypt($passwd);
	else $passwd = $user['pass'];

   FWL_CheckDuplePost($Content,$Author,"T_Stories");
  
   if ($CONF['BLOCK_IP']) KWL_PostBlockIP($Content,$Author,$AuthorEmail);
   elseif ($CONF['SPAM_CHECK']==1) {
		KWL_SpamCheck($summ,$Author,$AuthorEmail);
		KWL_SpamCheck($Content,$Author,$AuthorEmail);
	} elseif ($CONF['SPAM_CHECK']==2) {
		$summ = KWL_ProofSpam($summ);
		$Content = KWL_ProofSpam($Content);
	}

   if ($CONF['story_parse']) {
      if ($ParseLevel < 2 || $ParseLevel > 4) $ParseLevel = $CONF['ParseLevel'];
   } else $ParseLevel = $CONF['ParseLevel'];
	
	if (!empty($autostory)) {
		$program_time = mktime($hour,$min,0,$month,$day,$year);
		$sql  = "INSERT INTO T_Auto_Story ";
		$sql .= "VALUES ('$rid', '". KWL_GetIP(). "', $Topic, '";
		$sql .= $Heading ."', '$summ', '$Content', ";
		$sql .= "'$Author', '$AuthorEmail', '$AuthorURL',";
		$sql .= $EmailComments=="on" ? "1," : "0,";
		$sql .= "$program_time,";
		$sql .= "'$file[name]', '$updir', '$file[size]',";
		$sql  .= "'$passwd', $ParseLevel)";
		if (SqlQuery($sql)) {
			KWL_StoryLink($Links,$rid);
			include("include/header.inc.php");
			$A['Content'] = "<br />". _PROGRAM_SAVED ."<br />";
			$A['Heading'] = _CONTRIB;
			KWL_DrawMain($A);
			include("include/footer.inc.php");
			KWL_Redirect("admin/autostory.php",1,3);
			exit;
		} else {
			KWL_ErrorLog(_UNABLE_STORY . " $rid");
			KWL_ShowError(_SQL_ERROR);
		}	
	} else {
		$sql	= "INSERT INTO T_Stories ";
		$sql	.= "(Rid,Verified,Topic,Heading,Summary,Content,Host,Author,AuthorEmail,AuthorURL,EmailComments,Hits,Birthstamp,Repostamp,bofile,bcfile,bfsize,passwd,ParseLevel) ";
		$sql	.= "VALUES (";
		$sql	.= "'" . $rid . "',";
		$sql	.= $valflag;
		$sql	.= $CONF["Topics"]>0 ? $Topic : 0;
		$sql	.= ",'$Heading', '$summ', '$Content',";
		$sql	.= "'" . KWL_GetIP() . "',";
		$sql	.= "'$Author', '$AuthorEmail', '$AuthorURL',";
		$sql	.= $EmailComments=="on" ? "1," : "0,";
		$sql	.= "1, now(), now(),";
		$sql	.= "'$file[name]', '$updir', '$file[size]',";
		$sql	.= "'$passwd', $ParseLevel)";
		if (SqlQuery($sql)) {
			KWL_StoryLink($Links,$rid);
			if (!$CONF['Moderation'] || $CONF['Moderation'] == 3 || $CONF['admin_login']) {
            register_shutdown_function(KWL_ExportRdf());
         }
			if ($CONF['MailingList'] && $valflag == "'Y',") {
            register_shutdown_function(KWL_MailToList($rid));
         }
			if ($CONF['Moderation'] == "2" || $CONF['Moderation'] == "3") {
				register_shutdown_function(KWL_NotifyAdmin($rid));
				register_shutdown_function(KWL_NotifyModer($rid));
			}
			include("include/header.inc.php");
			if ($CONF['Moderation']==1 || $CONF['Moderation']==2) 
				$A['Content'] = _STORY_MOD;
			else $A['Content'] = _STORYOK;
			$A['Content'] = "<br /><center><b>". $A['Content'] 
			            ."</b><p />[ <a href=\"$CONF[G_URL]\">"
							. KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
							. KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
			$A['Heading'] = _CONTRIB;
			KWL_DrawMain($A);
			include("include/footer.inc.php");
			KWL_Redirect("$CONF[G_URL]",1,3);
			exit;
		} else {
			KWL_ErrorLog(_UNABLE_STORY . " $rid");
			KWL_ShowError(_SQL_ERROR);
		}
	}
}

include("include/header.inc.php");
$_POST['Birthstamp'] = date("Y-m-d H:i:s",time());
$_POST['Host'] = KWL_GetIP();
$_POST['Rid'] = ""; $_POST['Hits'] = "";

if (!empty($_POST['topic_mv']) && $_POST['topic_mv'] != $Topic) {
   $path = $CONF['G_PATH'] . "/upload/";
   if (!file_exists($path . $Topic)) @mkdir($path . $Topic,0755);
   @exec($exec['mv'] ." \"". $path . $_POST['topic_mv'] ."/". $updir ."\" \"". $path . $Topic ."\"");
}

if (!empty($file['name']) && file_exists($CONF['G_PATH'].'/upload/'.$Topic.'/'.$updir.'/'.$file['name'])) {
   $_POST['bofile'] = $file['name'];
   $_POST['bcfile'] = $updir;
   $_POST['bfsize'] = $file['size'];
} else $_POST['bofile'] = '';

KWL_DrawStory(KWL_string_parse($_POST,"stripslashes"),'',1);

$out = new KWL_Html;
$VAR["Heading"] = _PRESTORY;
$VAR["Content"] = _PRETEXT;
$VAR["Content"] .= $out->form_start("preview.php","Preview",$CONF['FILE_UPLOAD'])
. $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>". _TITLE .":</td>
	<td>". $out->input_form("text","Heading",KWL_PrepareHtml(stripslashes($Heading)),$size['titl'],96) ."</td>
</tr>
<tr>
	<td>". _TOPIC .":</td>
	<td>". $out->topicsel($Topic,"post") ."
</tr>";

if ($CONF["SummaryLength"]) {
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _SUMMARY .":<br />
	". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml(stripslashes($summ))) ."</td>
</tr>";
}

$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _STORY .": ". KWL_FormResizer("Preview.Content",$size['text'],10) ." 
<br />". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml(stripslashes($Content))) ."
	</td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['story_parse'],$ParseLevel) ."
   </td>
</tr>";

/*==  ũ ==*/
if ($Links) {
	$foo = $Links;
	for (reset($foo);$k=key($foo);next($foo)) {
	$foo[$k] = KWL_UrlCheck($foo[$k]);
	$VAR["Content"] .= "<tr><td>" . $k . ":</td>";
	$VAR["Content"] .= "<td>". $out->input_form("text","Links[$k]",$foo[$k],$size['name'],128) ."</td></tr>\n";
	}
}

if ($CONF['FILE_UPLOAD']) {
   if (!empty($file['name']) && file_exists($CONF['G_PATH'].'/upload/'.$Topic.'/'.$updir.'/'.$file['name'])) {
      $VAR["Content"] .= "<tr><td>"._UPLOADED_FILE.":</td>
         <td><a href=\"$CONF[G_URL]/upload/$Topic/$updir/$file[name]\" target=\"_blank\">". 
         htmlspecialchars($file['name']) ."</a> (". KWL_FileHSize($file['size']) .") ".
         $out->input_form("submit","killfile",_UPLOADED_FILE_DEL).
         $out->input_form("hidden","file[name]",$file['name']).
         $out->input_form("hidden","file[size]",$file['size']).
         $out->input_form("hidden","topic_mv",$Topic).
         $out->input_form("hidden","updir",$updir). "</td></tr>";
   } else {
      $VAR["Content"] .= "<tr><td>"._FILE.":</td><td>" .
         $out->input_form("hidden","max_file_size",$CONF['FILE_MAX_SIZE']) .
         $out->input_form("file","userfile",'',KWL_FormSize(15),256) ."<br />".
         "</td></tr>";
   }
}

if ($CONF['admin_login'] && $CONF['Auto_Posting']) {
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"._STORY_PROGRAM.": 
	". $out->select("autostory",array(_NOTUSE,_USE),$autostory) ."
	<br />". _CURRENT_TIME .": ". date("Y-m-d H:i", time()) ."</td>
</tr>
<tr>
	<td colspan=\"2\">". KWL_MakeTimeSelect($year,$day,$month,$hour,$min) ."</td>
</tr>
";
}
settype($passwd, "string");
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"
	. $out->input_form("hidden","Author",htmlspecialchars(stripslashes($Author)))
	. $out->input_form("hidden","AuthorEmail",htmlspecialchars(stripslashes($AuthorEmail)))
	. $out->input_form("hidden","AuthorURL",$AuthorURL)
	. $out->input_form("hidden","EmailComments",$EmailComments)
	. $out->input_form("hidden","hcode",KWL_HcodeMake(KWL_GetConf("SiteKey")))
	. $out->input_form("hidden","passwd",$passwd)
	. $out->input_form("submit","mode",_SUBMIT)
	. $out->input_form("submit","mode",_PREVIEW) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("include/footer.inc.php");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/preview.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
KWL_CheckLocalReferer(1);
if (!KWL_HcodeCheck(KWL_GetConf("SiteKey"),$_POST['hcode'])) KWL_Redirect("$CONF[G_URL]");

ini_set('upload_max_filesize',$CONF['FILE_MAX_SIZE']);

$head = _PREVIEW;

$AuthorEmail = KWL_EmailCheck($AuthorEmail);
if (empty($Author) || empty($AuthorEmail) || empty($Content) || empty($Heading)) {
   KWL_ShowError(_ERROR_INPUT_STORY);
}

/* check Author without login */
if (!$CONF['NoLogin_User'] && !$login) {
   if (SqlCount("T_Users","name",trim($Author))) KWL_ShowError(_MUST_LOGIN);
}

if (empty($Summary)) $summ = KWL_genSummary($Content);
else $summ = KWL_genSummary($Summary);

if (isset($_POST['killfile']) && $_POST['killfile'] == _UPLOADED_FILE_DEL) {
   @unlink("$CONF[G_PATH]/upload/$Topic/$updir/$file[name]");
   @unlink("$CONF[G_PATH]/upload/$Topic/$updir/$file[name]"."_t.jpg");
   @rmdir("$CONF[G_PATH]/upload/$Topic/$updir");
   unset($file,$updir);
}

if (!empty($file)) {
} else if (!$CONF['FILE_UPLOAD'] || empty($_FILES['userfile']['name'])) {
   $file['name'] = '';
   $updir = '';
   $file['size'] = 0;
} else {
   $updir = date("YmdHis",time());
   $file = KWL_FileUpload($_FILES['userfile'],"$CONF[G_PATH]/upload/$Topic",$updir,$CONF['FILE_MAX_SIZE']);
   if (!is_array($file)) KWL_ShowError(_UPLOAD_FAILED);	
}

settype($mode,"string");
if ($mode==_SUBMIT) {
   $rid	= KWL_getRid();
   if (!$CONF['Moderation'] || $CONF['admin_login'] || $CONF['Moderation']==3) 
      $valflag	= "'Y',";
   else $valflag	= "'N',";

	$Content = trim($Content);
	$summ = trim($summ);
   list($Heading,$Author) = KWL_PrepareHtml($Heading,$Author);
	if ($AuthorURL) $AuthorURL = KWL_UrlCheck($AuthorURL);
   if ($CONF['NoLogin_User']) KWL_SaveUserCookie($Author,$AuthorEmail,$AuthorURL);
	if ($CONF['ENABLE_EDIT'] && !$login) $passwd = crypt($passwd);
	else $passwd = $user['pass'];

   FWL_CheckDuplePost($Content,$Author,"T_Stories");
  
   if ($CONF['BLOCK_IP']) KWL_PostBlockIP($Content,$Author,$AuthorEmail);
   elseif ($CONF['SPAM_CHECK']==1) {
		KWL_SpamCheck($summ,$Author,$AuthorEmail);
		KWL_SpamCheck($Content,$Author,$AuthorEmail);
	} elseif ($CONF['SPAM_CHECK']==2) {
		$summ = KWL_ProofSpam($summ);
		$Content = KWL_ProofSpam($Content);
	}

   if ($CONF['story_parse']) {
      if ($ParseLevel < 2 || $ParseLevel > 4) $ParseLevel = $CONF['ParseLevel'];
   } else $ParseLevel = $CONF['ParseLevel'];
	
	if (!empty($autostory)) {
		$program_time = mktime($hour,$min,0,$month,$day,$year);
		$sql  = "INSERT INTO T_Auto_Story ";
		$sql .= "VALUES ('$rid', '". KWL_GetIP(). "', $Topic, '";
		$sql .= $Heading ."', '$summ', '$Content', ";
		$sql .= "'$Author', '$AuthorEmail', '$AuthorURL',";
		$sql .= $EmailComments=="on" ? "1," : "0,";
		$sql .= "$program_time,";
		$sql .= "'$file[name]', '$updir', '$file[size]',";
		$sql  .= "'$passwd', $ParseLevel)";
		if (SqlQuery($sql)) {
			KWL_StoryLink($Links,$rid);
			include("include/header.inc.php");
			$A['Content'] = "<br />". _PROGRAM_SAVED ."<br />";
			$A['Heading'] = _CONTRIB;
			KWL_DrawMain($A);
			include("include/footer.inc.php");
			KWL_Redirect("admin/autostory.php",1,3);
			exit;
		} else {
			KWL_ErrorLog(_UNABLE_STORY . " $rid");
			KWL_ShowError(_SQL_ERROR);
		}	
	} else {
		$sql	= "INSERT INTO T_Stories ";
		$sql	.= "(Rid,Verified,Topic,Heading,Summary,Content,Host,Author,AuthorEmail,AuthorURL,EmailComments,Hits,Birthstamp,Repostamp,bofile,bcfile,bfsize,passwd,ParseLevel) ";
		$sql	.= "VALUES (";
		$sql	.= "'" . $rid . "',";
		$sql	.= $valflag;
		$sql	.= $CONF["Topics"]>0 ? $Topic : 0;
		$sql	.= ",'$Heading', '$summ', '$Content',";
		$sql	.= "'" . KWL_GetIP() . "',";
		$sql	.= "'$Author', '$AuthorEmail', '$AuthorURL',";
		$sql	.= $EmailComments=="on" ? "1," : "0,";
		$sql	.= "1, now(), now(),";
		$sql	.= "'$file[name]', '$updir', '$file[size]',";
		$sql	.= "'$passwd', $ParseLevel)";
		if (SqlQuery($sql)) {
			KWL_StoryLink($Links,$rid);
			if (!$CONF['Moderation'] || $CONF['Moderation'] == 3 || $CONF['admin_login']) {
            register_shutdown_function(KWL_ExportRss());
         }
			if ($CONF['MailingList'] && $valflag == "'Y',") {
            register_shutdown_function(KWL_MailToList($rid));
         }
			if ($CONF['Moderation'] == "2" || $CONF['Moderation'] == "3") {
				register_shutdown_function(KWL_NotifyAdmin($rid));
				register_shutdown_function(KWL_NotifyModer($rid));
			}
			include("include/header.inc.php");
			if ($CONF['Moderation']==1 || $CONF['Moderation']==2) 
				$A['Content'] = _STORY_MOD;
			else $A['Content'] = _STORYOK;
			$A['Content'] = "<br /><center><b>". $A['Content'] 
			            ."</b><p />[ <a href=\"$CONF[G_URL]\">"
							. KWL_PrepareHtml($CONF['SiteName']) ."</a> - "
							. KWL_PrepareHtml($CONF['SiteSlogan']) ." ]</center><br />";
			$A['Heading'] = _CONTRIB;
			KWL_DrawMain($A);
			include("include/footer.inc.php");
			KWL_Redirect("$CONF[G_URL]",1,3);
			exit;
		} else {
			KWL_ErrorLog(_UNABLE_STORY . " $rid");
			KWL_ShowError(_SQL_ERROR);
		}
	}
}

include("include/header.inc.php");
$_POST['Birthstamp'] = date("Y-m-d H:i:s",time());
$_POST['Host'] = KWL_GetIP();
$_POST['Rid'] = ""; $_POST['Hits'] = "";

if (!empty($_POST['topic_mv']) && $_POST['topic_mv'] != $Topic) {
   $path = $CONF['G_PATH'] . "/upload/";
   if (!file_exists($path . $Topic)) @mkdir($path . $Topic,0755);
   @exec($exec['mv'] ." \"". $path . $_POST['topic_mv'] ."/". $updir ."\" \"". $path . $Topic ."\"");
}

if (!empty($file['name']) && file_exists($CONF['G_PATH'].'/upload/'.$Topic.'/'.$updir.'/'.$file['name'])) {
   $_POST['bofile'] = $file['name'];
   $_POST['bcfile'] = $updir;
   $_POST['bfsize'] = $file['size'];
} else $_POST['bofile'] = '';
$CONF['trackback'] = false; /* temp off for preview */
KWL_DrawStory(KWL_string_parse($_POST,"stripslashes"),'',1);

$out = new KWL_Html;
$VAR["Heading"] = _PRESTORY;
$VAR["Content"] = _PRETEXT;
$VAR["Content"] .= $out->form_start("preview.php","Preview",$CONF['FILE_UPLOAD'])
. $out->table_start("100%",'',0,0,3) ."
<tr>
	<td>". _TITLE .":</td>
	<td>". $out->input_form("text","Heading",KWL_PrepareHtml(stripslashes($Heading)),$size['titl'],96) ."</td>
</tr>
<tr>
	<td>". _TOPIC .":</td>
	<td>". $out->topicsel($Topic,"post") ."
</tr>";

if ($CONF["SummaryLength"]) {
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _SUMMARY .":<br />
	". $out->textarea("Summary",5,$size['text'],KWL_PrepareHtml(stripslashes($summ))) ."</td>
</tr>";
}

$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">". _STORY .": ". KWL_FormResizer("Preview.Content",$size['text'],10) ." 
<br />". $out->textarea("Content",10,$size['text'],KWL_PrepareHtml(stripslashes($Content))) ."
	</td>
</tr>
<tr>
   <td colspan=\"2\">". KWL_MakeSelectParse($CONF['story_parse'],$ParseLevel) ."
   </td>
</tr>";

/*==  ũ ==*/
if ($Links) {
	$foo = $Links;
	for (reset($foo);$k=key($foo);next($foo)) {
	$foo[$k] = KWL_UrlCheck($foo[$k]);
	$VAR["Content"] .= "<tr><td>" . $k . ":</td>";
	$VAR["Content"] .= "<td>". $out->input_form("text","Links[$k]",$foo[$k],$size['name'],128) ."</td></tr>\n";
	}
}

if ($CONF['FILE_UPLOAD']) {
   if (!empty($file['name']) && file_exists($CONF['G_PATH'].'/upload/'.$Topic.'/'.$updir.'/'.$file['name'])) {
      $VAR["Content"] .= "<tr><td>"._UPLOADED_FILE.":</td>
         <td><a href=\"$CONF[G_URL]/upload/$Topic/$updir/$file[name]\" target=\"new\">". 
         htmlspecialchars($file['name']) ."</a> (". KWL_FileHSize($file['size']) .") ".
         $out->input_form("submit","killfile",_UPLOADED_FILE_DEL).
         $out->input_form("hidden","file[name]",$file['name']).
         $out->input_form("hidden","file[size]",$file['size']).
         $out->input_form("hidden","topic_mv",$Topic).
         $out->input_form("hidden","updir",$updir). "</td></tr>";
   } else {
      $VAR["Content"] .= "<tr><td>"._FILE.":</td><td>" .
         $out->input_form("hidden","max_file_size",$CONF['FILE_MAX_SIZE']) .
         $out->input_form("file","userfile",'',KWL_FormSize(15),256) ."<br />".
         "</td></tr>";
   }
}

if ($CONF['admin_login'] && $CONF['Auto_Posting']) {
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"._STORY_PROGRAM.": 
	". $out->select("autostory",array(_NOTUSE,_USE),$autostory) ."
	<br />". _CURRENT_TIME .": ". date("Y-m-d H:i", time()) ."</td>
</tr>
<tr>
	<td colspan=\"2\">". KWL_MakeTimeSelect($year,$day,$month,$hour,$min) ."</td>
</tr>
";
}
settype($passwd, "string");
$VAR["Content"] .= "
<tr>
	<td colspan=\"2\">"
	. $out->input_form("hidden","Author",htmlspecialchars(stripslashes($Author)))
	. $out->input_form("hidden","AuthorEmail",htmlspecialchars(stripslashes($AuthorEmail)))
	. $out->input_form("hidden","AuthorURL",$AuthorURL)
	. $out->input_form("hidden","EmailComments",$EmailComments)
	. $out->input_form("hidden","hcode",KWL_HcodeMake(KWL_GetConf("SiteKey")))
	. $out->input_form("hidden","passwd",$passwd)
	. $out->input_form("submit","mode",_SUBMIT)
	. $out->input_form("submit","mode",_PREVIEW) ."</td>
</tr>". $out->table_end() . $out->form_end();

KWL_DrawMain($VAR);
include("include/footer.inc.php");
?>
